# Rate Limiting
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/rate-limiting#overview)
  * [How Rate Limiting Works](https://help.sap.com/docs/leanix/ea/rate-limiting#how-rate-limiting-works)
  * [Rate Limits for the Pathfinder API](https://help.sap.com/docs/leanix/ea/rate-limiting#rate-limits-for-the-pathfinder-api)
  * [Rate Limits for Ingesting SBOMs](https://help.sap.com/docs/leanix/ea/rate-limiting#rate-limits-for-ingesting-sboms)


Learn how our rate limiting in SAP LeanIX APIs works.
